#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.3
visibility:           public
id:                   pantry-0.8.3-LYKGr06GrkVKm7lGlBa7Aj
key:                  pantry-0.8.3-LYKGr06GrkVKm7lGlBa7Aj
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  6ded5c7d0547cc69b01c0a09c90037fa
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.3-LYKGr06GrkVKm7lGlBa7Aj
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-EwrTYsTfELe3d4orbILmv4
    ansi-terminal-1.1-Hf6fFmjaIfCVZ3DoDW5HB base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.4-1EjiiDpTeIF72fWqNpqIpu
    casa-types-0.0.3-4l0oySMEMjHKnlVB4bfq15
    conduit-1.3.6.1-KPHDCDDIHN1EOURpcrFXUe
    conduit-extra-1.3.8-1lTAw5MbR9d8jW8YQMIELA containers-0.6.7
    crypton-1.0.5-1z1P9gki3DpXKZxddhNPM
    crypton-conduit-0.2.3-ODRDZHeb8JCATwFUSq5lx
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.9-2Ib8lnLgDCaLmHleGe7QaZ
    generic-deriving-1.14.7-E45zydjQUReE3T5FFRTnL4
    hackage-security-0.6.3.2-EkvQiShKg3h31dO6NGhMC0
    hpack-0.38.0-yZ4ygwrGWAKpWN5z14rKP
    http-client-0.7.19-uRvF7eEYhRDNuWEwLS8eA
    http-client-tls-0.3.6.4-4YRJdpyh0LQFEcqojHieFc
    http-conduit-2.3.9.1-3jVRXfysx7LHah4LOBTB7z
    http-download-0.2.1.0-EuJuWINuZ8kHJeHngNrFSr
    http-types-0.12.4-D4ln0jiwEOhAKcR3fqSchY
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-HyBVnFdXLs0Dgiq4qkHmFH
    path-0.9.6-7raF4tLYHpHKU533QPH3ar
    path-io-1.8.2-JwlKMwQaeqM3ko5dANNoJw
    persistent-2.14.6.0-EsLhVXHaN4dEGHQ0lrXspL
    persistent-sqlite-2.13.3.0-CsyujRB8xVh5HNYfKOEYOa
    primitive-0.9.1.0-9K5vR1Mi21T8XGVzI2tm4J
    resourcet-1.3.0-1zDmXgfXfhGHcZ53EkSGgY
    rio-0.1.24.0-FcidF0Ma4YNv6HER3ssBf
    rio-orphans-0.1.2.0-K2dnEInQupg82IYYzFNmyi
    rio-prettyprint-0.1.9.0-SKWMyh0FZK92EnuYP4Vcp
    tar-conduit-0.4.1-44M5tIPe9OfHPIx6lG1UU8 text-2.0.2
    text-metrics-0.3.3-FGPBmpo5qec8F0jZAa41LA time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-7Q1StMrvuG9I60m4DIlvtT
    unliftio-0.2.25.1-5kFyykBV8QLAHqHdpZTooL
    unordered-containers-0.2.21-KyMpciGvYH9aykbB6p5Z
    vector-0.13.2.0-pkGAkHyCfVA94J1hIBHJi
    yaml-0.11.11.2-Gz9Bz4lbRgP2FR94qGDleq
    zip-archive-0.4.3.2-LMYqDQ0oUxCT9ZieCrqlA

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

